{ withSystem, self, inputs, ...}:
{
  flake = {
    nixosConfigurations = {
      stroopwafel = self.nixos-flake.lib.mkLinuxSystem {
        nixpkgs.hostPlatform = "x86_64-linux";
        imports = [
          inputs.impermanence.nixosModules.impermanence
          inputs.openstreetmap.nixosModules.openstreetmap
          self.nixosModules.base
          ./stroopwafel
          self.nixosModules.b12f
          self.nixosModules.audio
          self.nixosModules.bluetooth
          self.nixosModules.desktop-extended
          self.nixosModules.docker
          self.nixosModules.graphical
          self.nixosModules.office
          self.nixosModules.persistence
          self.nixosModules.portable
          self.nixosModules.printing
        ];
      };

      biolimo = self.nixos-flake.lib.mkLinuxSystem {
        nixpkgs.hostPlatform = "x86_64-linux";
        imports = [
          self.nixosModules.base
          ./biolimo
          self.nixosModules.b12f
          self.nixosModules.audio
          self.nixosModules.bluetooth
          self.nixosModules.desktop-extended
          self.nixosModules.docker
          self.nixosModules.graphical
          self.nixosModules.office
          self.nixosModules.portable
          self.nixosModules.printing
        ];
      };

      chocolatebar = self.nixos-flake.lib.mkLinuxSystem {
        nixpkgs.hostPlatform = "x86_64-linux";
        imports = [
          inputs.musnix.nixosModules.musnix
          self.nixosModules.base
          ./chocolatebar
          self.nixosModules.b12f
          self.nixosModules.audio
          self.nixosModules.desktop-extended
          self.nixosModules.docker
          self.nixosModules.gaming
          self.nixosModules.graphical
          self.nixosModules.office
          self.nixosModules.printing
          self.nixosModules.virtualisation
          self.nixosModules.wireshark
        ];
      };

      droppie = self.nixos-flake.lib.mkLinuxSystem {
        nixpkgs.hostPlatform = "x86_64-linux";
        imports = [
          inputs.impermanence.nixosModules.impermanence
          self.nixosModules.base
          ./droppie
          self.nixosModules.yule
          self.nixosModules.acme
          self.nixosModules.proxy
          self.nixosModules.persistence
        ];
      };

      pie = self.nixos-flake.lib.mkLinuxSystem {
        nixpkgs.hostPlatform = "aarch64-linux";
        imports = [
          self.nixosModules.base
          inputs.nixos-hardware.nixosModules.raspberry-pi-4
          ./pie
          self.nixosModules.yule
          self.nixosModules.acme
          self.nixosModules.proxy
          self.nixosModules.docker
          self.nixosModules.invoiceplane
        ];
      };

      frikandel = self.nixos-flake.lib.mkLinuxSystem {
        nixpkgs.hostPlatform = "x86_64-linux";
        imports = [
          self.nixosModules.base
          ./frikandel
          self.nixosModules.yule
          self.nixosModules.acme
          self.nixosModules.proxy
          self.nixosModules.docker
        ];
      };

      # maoam = self.nixos-flake.lib.mkLinuxSystem {
      #   nixpkgs.hostPlatform = "aarch64-linux";
      #   imports = [
      #     self.nixosModules.base
      #     ./maoam
      #     self.nixosModules.yule
      #   ];
      # };

      iso = self.nixos-flake.lib.mkLinuxSystem {
        nixpkgs.hostPlatform = "x86_64-linux";
        imports = [
          "${inputs.nixpkgs}/nixos/modules/installer/cd-dvd/installation-cd-minimal.nix"
          self.nixosModules.base
          ./iso
          self.nixosModules.nixos
        ];
      };

      iso-arm = self.nixos-flake.lib.mkLinuxSystem {
        nixpkgs.hostPlatform = "aarch64-linux";
        nixpkgs.buildPlatform = "x86_64-linux";
        imports = [
          "${inputs.nixpkgs}/nixos/modules/installer/cd-dvd/installation-cd-minimal.nix"
          self.nixosModules.base
          ./iso
          self.nixosModules.nixos
        ];
      };

      iso-graphical = self.nixos-flake.lib.mkLinuxSystem {
        nixpkgs.hostPlatform = "x86_64-linux";
        imports = [
          "${inputs.nixpkgs}/nixos/modules/installer/cd-dvd/installation-cd-minimal.nix"
          self.nixosModules.base
          ./iso
          self.nixosModules.nixos
          self.nixosModules.graphical
          self.nixosModules.audio
          self.nixosModules.bluetooth
          ({ ... }: { pub-solar.graphical.wayland.software-renderer.enable = true; })
        ];
      };
    };
  };
}
