{
  config,
  pkgs,
  lib,
  flake,
  ...
}:
with lib; let
  psCfg = config.pub-solar;
  xdg = config.home-manager.users."${psCfg.user.name}".xdg;
in {
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  services.openssh.openFirewall = true;

  pub-solar.user.publicKeys = [
    "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIBB5XaH02a6+TchnyQED2VwaltPgeFCbildbE2h6nF5e root@nachtigall"
  ];

  boot.kernelParams = [
    "boot.shell_on_fail=1"
    # Hack so that network is considered up by boot.initrd.network and postCommands gets executed.
    "ip=127.0.0.1:::::lo:none"
  ];
  boot.initrd.availableKernelModules = [ "tg3" ];
  boot.initrd.network = {
    enable = true;
    ssh = {
      enable = true;
      port = 2222;
      authorizedKeys = flake.self.publicKeys;
      hostKeys = ["/persist/etc/secrets/initrd/ssh_host_ed25519_key"];
      shell = "/bin/cryptsetup-askpass";
    };
    postCommands = ''
      ip link set dev enp2s0f0 up

      ip addr add 192.168.178.3/32 dev enp2s0f0
      ip route add 192.168.178.1 dev enp2s0f0
      ip route add default via 192.168.178.1 dev enp2s0f0

      ip -6 addr add 2a02:908:5b1:e3c0:3::/128 dev enp2s0f0
      ip -6 addr add fe80:b12f:acab:1312:acab:3::/128 dev enp2s0f0
    '';
  };

  # ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIBZQSephFJU0NMbVbhwvVJ2/m6jcPYo1IsWCsoarqKin root@droppie
  age.secrets."droppie-ssh-root.key" = {
    file = "${flake.self}/secrets/droppie-ssh-root.key.age";
    path = "/home/${psCfg.user.name}/.ssh/id_ed25519";
    mode = "400";
    owner = psCfg.user.name;
  };

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "21.11"; # Did you read the comment?
}
