{
  config,
  pkgs,
  lib,
  flake,
  ...
}:
with lib; let
  psCfg = config.pub-solar;
  xdg = config.home-manager.users."${psCfg.user.name}".xdg;
in {
  boot.loader.grub.enable = true;
  boot.loader.grub.efiSupport = true;
  boot.loader.grub.efiInstallAsRemovable = true;
  boot.loader.grub.device = "nodev";
  boot.loader.timeout = 5;
  boot.loader.grub.configurationLimit = 24;

  boot.loader.efi.canTouchEfiVariables = false;
  boot.loader.systemd-boot.enable = false;
  boot.loader.generic-extlinux-compatible.enable = false;

  boot.supportedFilesystems = [ "zfs" ];
  boot.kernelPackages = pkgs.linuxPackages_6_1_hardened;

  boot.kernelParams = [
    "boot.shell_on_fail=1"
    # Hack so that network is considered up by boot.initrd.network and postCommands gets executed.
    "ip=127.0.0.1:::::lo:none"
  ];
  # See https://discourse.nixos.org/t/ssh-and-network-in-initrd-on-raspberry-pi-4/6289/3
  boot.initrd.availableKernelModules = [ "genet" ];
  boot.initrd.network = {
    enable = true;
    ssh = {
      enable = true;
      port = 2222;
      authorizedKeys = flake.self.publicKeys;
      hostKeys = ["/etc/secrets/initrd/ssh_host_ed25519_key"];
      shell = "/bin/cryptsetup-askpass";
    };
    postCommands = ''
      ip link set dev enabcm6e4ei0 up

      ip addr add 192.168.178.2/32 dev enabcm6e4ei0
      ip route add 192.168.178.1 dev enabcm6e4ei0
      ip route add default via 192.168.178.1 dev enabcm6e4ei0

      ip -6 addr add 2a02:908:5b1:e3c0:2::/128 dev enabcm6e4ei0
      ip -6 addr add fe80:b12f:acab:1312:acab:2::/128 dev enabcm6e4ei0
    '';
  };

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "23.11"; # Did you read the comment?
}
